@@ -1,10 +1,11 @@
-use crate::errors::Error;
-use crate::log::SchemaEvent;
-use crate::{Key, Value};
 use std::collections::HashMap;
 use std::marker::PhantomData;
 use std::sync::RwLockWriteGuard;
 
+use crate::errors::Error;
+use crate::log::SchemaEvent;
+use crate::{Key, Value};
+
 pub trait Transaction<'b, In> {
     fn transaction<F, Out>(&'b self, tx: F) -> Result<Out, Error>
     where
@@ -38,6 +39,10 @@ where
         self.data.get(key).cloned()
     }
 
+    pub fn get_all(&self) -> HashMap<K, V> {
+        self.data.clone()
+    }
+
     pub fn exists(&self, key: &K) -> bool {
         self.data.contains_key(key)
     }
